@@ -207,9 +207,7 @@ class RfTestCase:
         return KeywordCall.from_params(
             assign=tuple(interaction.cbr_parameters.values()),
             name=f"{import_prefix}{interaction.name}",
-            args=tuple(
-                cbv_parameters
-            ),  
+            args=tuple(cbv_parameters),
             indent=interaction_indent,
         )
 
